@@ -11,7 +11,6 @@ class Incomes(Resource):
         link: str,
         *,
         token: str = None,
-        encryption_key: str = None,
         save_data: bool = True,
         raise_exception: bool = False,
         **kwargs: Dict,
@@ -21,8 +20,6 @@ class Incomes(Resource):
 
         if token:
             data.update(token=token)
-        if encryption_key:
-            data.update(encryption_key=encryption_key)
 
         return self.session.post(
             self.endpoint, data=data, raise_exception=raise_exception, **kwargs
